@@ -1,12 +1,11 @@
-#!/usr/bin/python2
+#!/usr/bin/env python
 
-import os
 import sys
 sys.path.insert(0, '.')
 
 import py.path
 
-from lib_pypy.tools.build_cffi_imports import create_cffi_import_libraries
+from pypy.tool.build_cffi_imports import create_cffi_import_libraries
 
 
 class FakeOptions(object):
@@ -18,7 +17,7 @@ class FakeOptions(object):
         raise AttributeError()
 
 
-os.environ['LD_LIBRARY_PATH'] = 'pypy/goal'
-pypy_c = py.path.local('pypy/goal/pypy3-c')
+pypy_c = py.path.local('pypy/goal/pypy-c')
 options = FakeOptions()
-create_cffi_import_libraries(pypy_c, options, '.')
+basedir = py.path.local('.')
+create_cffi_import_libraries(pypy_c, options, basedir)
