@@ -17,13 +17,16 @@ find debian/$pkg \( \
      -o -name '*.pickle' \
      \) -delete
 
-# Remove empty directories, because pypy3clean will
-find debian/$pkg/usr/lib/pypy3.11 -type d -empty -delete
+# Remove empty directories, because pypyclean will
+find debian/$pkg/usr/lib/pypy/lib-python -type d -empty -delete
 
 # Nothing in the stdlib should be executable
-chmod -R a-x+X debian/$pkg/usr/lib/pypy3.11/
+chmod -R a-x+X debian/$pkg/usr/lib/pypy/lib-python/
+if [ "$pkg" = "pypy-lib" ]; then
+	chmod -R a-x+X debian/$pkg/usr/lib/pypy/lib_pypy/
+fi
 
 # Fix interpreters
 find debian/$pkg \
      -name '*.py' -print0 \
-     | xargs -0 sed -i -e '1s|^#!.*python.*|#!/usr/bin/pypy3|'
+     | xargs -0 sed -i -e '1s|^#!.*python.*|#!/usr/bin/pypy|'
