@@ -69,8 +69,6 @@ with codecs.open('debian/pypy.substvars', 'a', encoding='UTF-8') as f:
 path = 'debian/pypy-lib/usr/share/dh-python/dist/pypy'
 os.makedirs(path)
 with codecs.open(os.path.join(path, 'pypy-cffi'), 'w', encoding='UTF-8') as f:
-    f.write('cffi pypy-cffi-backend-api-{target}\n'.format(**subst))
-    # Disabled until we can use versioned provides (blocked by #786803)
-    # f.write('cffi pypy-cffi-backend-api-min (<= {target}), '
-    #         'pypy-cffi-backend-api-max (>= {target})\n'
-    #         .format(**subst))
+    f.write('cffi pypy-cffi-backend-api-min (<= {target}), '
+            'pypy-cffi-backend-api-max (>= {target})\n'
+            .format(**subst))
